@@ -11,6 +11,7 @@
 // lib
 #include "textcharcodec.hpp"
 #include "ebcdic1047charcodec.hpp"
+#include "ibm874charcodec.hpp"
 #include "jisx0201charcodec.hpp"
 #include "usasciicharcodec.hpp"
 // Qt
@@ -24,7 +25,8 @@ const QStringList& CharCodec::codecNames()
     // first call?
     if (codecNames.isEmpty()) {
         codecNames = TextCharCodec::codecNames();
-        codecNames.reserve(codecNames.size() + 3);
+        codecNames.reserve(codecNames.size() + 4);
+        codecNames.insert(codecNames.size()-2, IBM874CharCodec::codecName()); // insert at place of TextCharCodec one
         codecNames.append(USASCIICharCodec::codecName());
         codecNames.append(EBCDIC1047CharCodec::codecName());
         codecNames.append(JISX0201CharCodec::codecName());
@@ -43,6 +45,8 @@ CharCodec* CharCodec::createCodec(const QString& name)
         result = USASCIICharCodec::create();
     } else if (EBCDIC1047CharCodec::codecName() == name) {
         result = EBCDIC1047CharCodec::create();
+    } else if (IBM874CharCodec::codecName() == name) {
+        result = IBM874CharCodec::create();
     } else if (JISX0201CharCodec::codecName() == name) {
         result = JISX0201CharCodec::create();
     } else {
