@@ -19,7 +19,7 @@ public:
     explicit Latin1StringData(StringDataInformation* parent);
     ~Latin1StringData() override;
 
-    qint64 read(Okteta::AbstractByteArrayModel* input, Okteta::Address address, BitCount64 bitsRemaining) override;
+    qint64 read(const Okteta::AbstractByteArrayModel* input, Okteta::Address address, BitCount64 bitsRemaining) override;
     BitCount32 sizeAt(uint i) const override;
     BitCount32 size() const override;
     QString completeString(bool skipInvalid = false) const override;
