@@ -20,8 +20,12 @@ class KASTENCONTROLLERS_EXPORT FileSystemBrowserToolViewFactory : public Abstrac
 {
 public:
     FileSystemBrowserToolViewFactory();
+    FileSystemBrowserToolViewFactory(const FileSystemBrowserToolViewFactory&) = delete;
+
     ~FileSystemBrowserToolViewFactory() override;
 
+    FileSystemBrowserToolViewFactory& operator=(const FileSystemBrowserToolViewFactory&) = delete;
+
 public: // AbstractToolViewFactory API
     AbstractToolView* create(AbstractTool* tool) const override;
 
