@@ -7,6 +7,7 @@
 */
 
 #include "partfactory.hpp"
+#include "partfactory-config.hpp"
 
 // part
 #include "part.hpp"
@@ -23,7 +24,6 @@
 #if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
 #include <KPluginMetaData>
 #endif
-#include <KLocalizedString>
 
 OktetaPartFactory::OktetaPartFactory()
 #if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
